"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.applyLint = exports.applyRomeLint = void 0;
const fs_1 = require("fs");
const helpers_fn_1 = require("helpers-fn");
const lint_fn_1 = require("lint-fn");
function checkShouldContinue(result, label, debug) {
    if (debug)
        console.log(result, label);
    if (!result) {
        return true;
    }
    (0, helpers_fn_1.log)(`File is linted "${label}"`, 'box');
    (0, helpers_fn_1.log)('sep');
    return false;
}
async function applyRomeLint(fileName, directory) {
    if (!(0, fs_1.existsSync)(fileName)) {
        (0, helpers_fn_1.log)(`${fileName} is deleted`, 'error');
        return true;
    }
    const command = `rome check ${fileName} --apply-suggested`;
    let logs = await (0, helpers_fn_1.exec)({ cwd: directory, command });
    console.log(logs, 'logs');
}
exports.applyRomeLint = applyRomeLint;
async function applyLint(fileName, forceTypescript) {
    const debug = false;
    if (!(0, fs_1.existsSync)(fileName)) {
        (0, helpers_fn_1.log)(`${fileName} is deleted`, 'error');
        return true;
    }
    (0, helpers_fn_1.log)('sep');
    (0, helpers_fn_1.log)(`will lint ${fileName}`, 'info');
    (0, helpers_fn_1.log)('sep');
    const baseProps = {
        filePath: fileName,
        debug,
        forceTypescript,
        useAlternativeExecCommand: false,
    };
    const initialLintResult = await (0, lint_fn_1.lintFn)(baseProps);
    if (!checkShouldContinue(initialLintResult, 'initial', debug))
        return true;
    const lintResultWithOuter = await (0, lint_fn_1.lintFn)({
        ...baseProps,
        prettierSpecialCase: 'outer',
    });
    if (!checkShouldContinue(lintResultWithOuter, 'outer', debug))
        return true;
    const lintResultWithLocal = await (0, lint_fn_1.lintFn)({
        ...baseProps,
        prettierSpecialCase: 'local',
    });
    if (!checkShouldContinue(lintResultWithLocal, 'local', debug))
        return true;
    (0, helpers_fn_1.log)('File failed to be linted', 'error');
    return false;
}
exports.applyLint = applyLint;
